@@ -1,24 +1,23 @@
 /* Main command processing loop.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2010 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2011 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
-	This program is free software; you can redistribute it and/or modify it
-	under the terms of the GNU General Public License as published by the
-	Free Software Foundation; either version 2, or (at your option) any
-	later version.
-	
-	This program is distributed in the hope that it will be useful, but
-	WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-	General Public License for more details.
-	
-	You should have received a copy of the GNU General Public License along
-	with this program; see the file COPYING.  If not, write to the Free
-	Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-	02111-1307, USA.  */
+	This library is free software; you can redistribute it and/or modify it
+	under the terms of the GNU General Public License as published by
+	the Free Software Foundation; either version 3 of the License, or (at your
+	option) any later version.
+
+	This library is distributed in the hope that it will be useful, but
+	WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+	or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+	for more details.
+
+	You should have received a copy of the GNU General Public License
+	along with this program; if not, see <http://www.gnu.org/licenses/>.  */
+
 
 #include "ne.h"
 #include "version.h"
@@ -270,54 +269,98 @@ int do_action(buffer *b, action a, int c, unsigned char *p) {
 		move_inc_down(b);
 		return OK;
 
-	case SETBOOKMARK_A:
 	case UNSETBOOKMARK_A:
-	case GOTOBOOKMARK_A:
-		/* *p can be  "", "-", "0".."9", for which, respectively, */
-		/*  c becomes  1,  0,   1 .. 10. Anything else is out of range. */
-		if (p) {
-			if (p[0]) {
-				if (!p[1]) {
-					if (*p == '-') c = 0;
-					else c = *p - '0' + 1;
-				}
-				else c = -1;
-			}
-			else c = 1;
+		if (p && p[0]=='*' && !p[1]) { /* Special parm "*" for UNSETBOOKMARK_A */
+			b->bookmark_mask = b->cur_bookmark = 0;
+			print_message("All BookMarks cleared.");
 			free(p);
-			if (c < 0 || c >= NUM_BOOKMARKS) return BOOKMARK_OUT_OF_RANGE;
-		}
-		else 
-			c = 1;
-		switch(a) {
-		case SETBOOKMARK_A:
-			b->bookmark[c].pos = b->cur_pos;
-			b->bookmark[c].line = b->cur_line;
-			b->bookmark_mask |= (1 << c);
-			snprintf(msg, MAX_MESSAGE_SIZE, "Bookmark %d set", c-1);
-			print_message(msg);
-			break;
-		case UNSETBOOKMARK_A:
-			if (! (b->bookmark_mask & (1 << c)))
-				return BOOKMARK_NOT_SET;
-			b->bookmark_mask &= ~(1 << c);
-			snprintf(msg, MAX_MESSAGE_SIZE, "Bookmark %d unset", c-1);
-			print_message(msg);
-			break;
-		case GOTOBOOKMARK_A:
-			if (! (b->bookmark_mask & (1 << c))) return BOOKMARK_NOT_SET;
-			else {
-				const int prev_line = b->cur_line;
-				const int prev_pos  = b->cur_pos;
-				delay_update();
-				goto_line(b, b->bookmark[c].line);
-				goto_pos(b, b->bookmark[c].pos);
-				b->bookmark[0].line = prev_line;
-				b->bookmark[0].pos = prev_pos;
-				b->bookmark_mask |= 1;
+			return OK;
+		} /* Intentionally fall through to regular BOOKMARK parm parsing. */
+	case SETBOOKMARK_A:
+	case GOTOBOOKMARK_A:
+		{
+			int relative = 0;
+			/* *p can be  "", "-", "0".."9", "+1","-1", for which, respectively, */
+			/*  c becomes  1,  0,   1 .. 10, next,prev. Anything else is out of range. */
+			if (p) {
+				if ((p[0]=='+' || p[0]=='-') && p[1]=='1') {
+					if (b->cur_bookmark<1 || b->cur_bookmark>=NUM_BOOKMARKS) b->cur_bookmark = 1;
+					for (i=0; i<NUM_BOOKMARKS-1; i++) {
+						b->cur_bookmark = (b->cur_bookmark-1+NUM_BOOKMARKS-1+(p[0]=='+'?1:-1))%(NUM_BOOKMARKS-1)+1;
+						if ((a==SETBOOKMARK_A?~b->bookmark_mask:b->bookmark_mask) & (1<<b->cur_bookmark)) {
+							c = b->cur_bookmark;
+							relative = 1;
+							break;
+						}
+					}
+					if (i==NUM_BOOKMARKS-1) {
+						free(p);
+						switch (a) {
+						case SETBOOKMARK_A:
+							return NO_UNSET_BOOKMARKS_TO_SET;
+						case GOTOBOOKMARK_A:
+							return NO_SET_BOOKMARKS_TO_GOTO;
+						default:
+							return NO_SET_BOOKMARKS_TO_UNSET;
+						}
+					}
+				} else if (p[0]) {
+					if (!p[1]) {
+						if (*p == '-') c = 0;
+						else c = *p - '0' + 1;
+					}
+					else c = -1;
+				}
+				else c = 1;
+				free(p);
+				if (c < 0 || c >= NUM_BOOKMARKS) return INVALID_BOOKMARK_DESIGNATION;
 			}
+			else 
+				c = 1;
+			switch(a) {
+			case SETBOOKMARK_A:
+				b->bookmark[c].pos = b->cur_pos;
+				b->bookmark[c].line = b->cur_line;
+				b->bookmark[c].cur_y = b->cur_y;
+				b->bookmark_mask |= (1 << c);
+				b->cur_bookmark = c;
+				snprintf(msg, MAX_MESSAGE_SIZE, "Bookmark %c set", c>0?'0'+c-1 : '-');
+				print_message(msg);
+				break;
+			case UNSETBOOKMARK_A:
+				if (! (b->bookmark_mask & (1 << c)))
+					return BOOKMARK_NOT_SET;
+				b->bookmark_mask &= ~(1 << c);
+				snprintf(msg, MAX_MESSAGE_SIZE, "Bookmark %c unset", c>0?'0'+c-1 : '-');
+				print_message(msg);
+				break;
+			case GOTOBOOKMARK_A:
+				if (! (b->bookmark_mask & (1 << c))) return BOOKMARK_NOT_SET;
+				else {
+					const int prev_line = b->cur_line;
+					const int prev_pos  = b->cur_pos;
+					const int cur_y     = b->cur_y;
+					b->cur_bookmark = c;
+					int  avshift;
+					delay_update();
+					goto_line(b, b->bookmark[c].line);
+					goto_pos(b, b->bookmark[c].pos);
+					if (avshift = b->cur_y - b->bookmark[c].cur_y) {
+						snprintf(msg, MAX_MESSAGE_SIZE, "%c%d", avshift > 0 ? 'T' :'B', avshift > 0 ? avshift : -avshift);
+						adjust_view(b,msg);
+					}
+					b->bookmark[0].line  = prev_line;
+					b->bookmark[0].pos   = prev_pos;
+					b->bookmark[0].cur_y = cur_y;
+					b->bookmark_mask |= 1;
+					if (relative) {
+						snprintf(msg, MAX_MESSAGE_SIZE, "At Bookmark %c", c>0?'0'+c-1 : '-');
+						print_message(msg);
+					}
+				}
+			}
+			return OK;
 		}
-		return OK;
 	
 	case GOTOLINE_A:
 		if (c < 0 && (c = request_number("Line", b->cur_line + 1))<0) return NUMERIC_ERROR(c);
@@ -359,6 +402,11 @@ int do_action(buffer *b, action a, int c, unsigned char *p) {
 		SET_USER_FLAG(b, c, opt.tabs);
 		return OK;
 
+	case AUTOMATCHBRACKET_A:
+		if (c < 0 && (c = request_number("Match mode (sum of 0:none, 1:brightness, 2:inverse, 4:bold, 8:underline)", b->opt.automatch))<0||c>15) return ((c) == ABORT ? OK : INVALID_MATCH_MODE);
+		b->opt.automatch = c;
+		return OK;
+
 	case INSERTTAB_A:
 		recording = b->recording;
 		b->recording = 0;
@@ -546,9 +594,10 @@ int do_action(buffer *b, action a, int c, unsigned char *p) {
 			if (b->cur_pos < b->cur_line_desc->line_len) {
 				/* Deletion inside a line. */
 				const int old_char = b->encoding == ENC_UTF8 ? utf8char(&b->cur_line_desc->line[b->cur_pos]) : b->cur_line_desc->line[b->cur_pos];
+				const int old_attr = b->syn ? b->attr_buf[b->cur_pos] : 0;
 				delete_one_char(b, b->cur_line_desc, b->cur_line, b->cur_pos);
 				
-				update_deleted_char(b, old_char, b->cur_line_desc, b->cur_pos, b->cur_char, b->cur_y, b->cur_x);	
+				update_deleted_char(b, old_char, old_attr, b->cur_line_desc, b->cur_pos, b->cur_char, b->cur_y, b->cur_x);	
 				if (b->syn) update_line(b, b->cur_y, TRUE, TRUE);
 			}
 			else {
@@ -757,11 +806,15 @@ int do_action(buffer *b, action a, int c, unsigned char *p) {
 			buffer *dup = get_buffer_named(p);
 
 			/* 'c' -- flag meaning "Don't prompt if we've ever responded 'yes'." */
-			if (!dup || dup == b || (dprompt && !c ) || (dprompt = request_response(b, info_msg[SAME_NAME], FALSE))) {
+			if (!dup || dup == b || (dprompt && !c) || (dprompt = request_response(b, info_msg[SAME_NAME], FALSE))) {
 				b->syn = NULL; /* So that autoprefs will load the right syntax. */
 				if (b->opt.auto_prefs && extension(p)) load_auto_prefs(b, extension(p));
 				error = load_file_in_buffer(b, p);
-				if (error != FILE_IS_MIGRATED && error != FILE_IS_DIRECTORY) change_filename(b, p);
+				if (error != FILE_IS_MIGRATED 
+					&& error != FILE_IS_DIRECTORY 
+					&& error != IO_ERROR 
+					&& error != FILE_IS_TOO_LARGE 
+					&& error != OUT_OF_MEMORY) change_filename(b, p);
 				print_error(error);
 				reset_window();
 				return OK;
@@ -772,7 +825,9 @@ int do_action(buffer *b, action a, int c, unsigned char *p) {
 		return ERROR;
 
 	case ABOUT_A:
-		print_message(ABOUT_MSG);
+	   about(1);
+	   c = get_key_code();
+	   about(0);
 		return OK;
 
 	case REFRESH_A:
