@@ -1,24 +1,22 @@
 /* Buffer handling functions, including allocation, deallocation, and I/O.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2010 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2011 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
-	This program is free software; you can redistribute it and/or modify it
-	under the terms of the GNU General Public License as published by the
-	Free Software Foundation; either version 2, or (at your option) any
-	later version.
-	
-	This program is distributed in the hope that it will be useful, but
-	WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-	General Public License for more details.
-	
-	You should have received a copy of the GNU General Public License along
-	with this program; see the file COPYING.  If not, write to the Free
-	Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-	02111-1307, USA.  */
+	This library is free software; you can redistribute it and/or modify it
+	under the terms of the GNU General Public License as published by
+	the Free Software Foundation; either version 3 of the License, or (at your
+	option) any later version.
+
+	This library is distributed in the hope that it will be useful, but
+	WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+	or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+	for more details.
+
+	You should have received a copy of the GNU General Public License
+	along with this program; if not, see <http://www.gnu.org/licenses/>.  */
 
 
 #include "ne.h" 
@@ -187,6 +185,7 @@ buffer *alloc_buffer(const buffer * const cur_b) {
 
 		b->opt.insert         =
 		b->opt.tabs           =
+		b->opt.automatch      =
 		b->opt.do_undo        =
 		b->opt.auto_prefs     = 1;
 
@@ -199,6 +198,7 @@ buffer *alloc_buffer(const buffer * const cur_b) {
 			b->opt.cur_clip       = cur_b->opt.cur_clip;
 			b->opt.tab_size       = cur_b->opt.tab_size;
 			b->opt.tabs           = cur_b->opt.tabs;
+			b->opt.automatch      = cur_b->opt.automatch;
 			b->opt.right_margin   = cur_b->opt.right_margin;
 
 			b->opt.free_form      = cur_b->opt.free_form;
@@ -1149,8 +1149,8 @@ int load_file_in_buffer(buffer * const b, const char *name) {
 	
 	name = tilde_expand(name);
 
-	if (is_migrated(name)) return FILE_IS_MIGRATED;
 	if (is_directory(name)) return FILE_IS_DIRECTORY;
+	if (is_migrated(name)) return FILE_IS_MIGRATED;
     
 	if ((fh = open(name, READ_FLAGS)) >= 0) {
 		result = load_fh_in_buffer(b, fh);
@@ -1172,8 +1172,8 @@ int load_file_in_buffer(buffer * const b, const char *name) {
 
 int load_fh_in_buffer(buffer *b, int fh) {
 	
-
-	int i, len, num_lines;
+	off_t len;
+	int i, num_lines;
 	encoding_type encoding;
 	unsigned char *p, *q;
 	char_pool *cp;
@@ -1184,7 +1184,8 @@ int load_fh_in_buffer(buffer *b, int fh) {
          
 	len = lseek(fh, 0, SEEK_END);
 
-	if (len < 0 || lseek(fh, 0, SEEK_SET)<0) return IO_ERROR;
+	if (len < 0 || lseek(fh, 0, SEEK_SET) < 0) return IO_ERROR;
+	if (len > INT_MAX) return FILE_IS_TOO_LARGE;
 
 	free_buffer_contents(b);
 
@@ -1202,6 +1203,7 @@ int load_fh_in_buffer(buffer *b, int fh) {
 		if (read(fh, cp->pool, len) < len) {
 			free_char_pool(cp);
 			release_signals();
+			clear_buffer(b);
 			return IO_ERROR;
 		}
 
@@ -1308,6 +1310,7 @@ int load_fh_in_buffer(buffer *b, int fh) {
 	}
 
 	release_signals();
+	clear_buffer(b);
 	return OUT_OF_MEMORY;
 }
 
@@ -1363,8 +1366,8 @@ int save_buffer_to_file(buffer *b, const char *name) {
 	
 	name = tilde_expand(name);
 
+	if (is_directory(name)) return FILE_IS_DIRECTORY;
 	if (is_migrated(name)) return FILE_IS_MIGRATED;
-	if (is_directory(name)) return FILE_IS_MIGRATED;
     
 	block_signals();
 
