@@ -1,24 +1,22 @@
 /* Clip handling functions.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2010 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2011 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
-	This program is free software; you can redistribute it and/or modify it
-	under the terms of the GNU General Public License as published by the
-	Free Software Foundation; either version 2, or (at your option) any
-	later version.
-	
-	This program is distributed in the hope that it will be useful, but
-	WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-	General Public License for more details.
-	
-	You should have received a copy of the GNU General Public License along
-	with this program; see the file COPYING.  If not, write to the Free
-	Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-	02111-1307, USA.  */
+	This library is free software; you can redistribute it and/or modify it
+	under the terms of the GNU General Public License as published by
+	the Free Software Foundation; either version 3 of the License, or (at your
+	option) any later version.
+
+	This library is distributed in the hope that it will be useful, but
+	WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+	or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+	for more details.
+
+	You should have received a copy of the GNU General Public License
+	along with this program; if not, see <http://www.gnu.org/licenses/>.  */
 
 
 #include "ne.h"
@@ -120,7 +118,7 @@ clip_desc *get_nth_clip(int n) {
 int copy_to_clip(buffer *b, int n, int cut) {
 
 	int i, pass, start_pos, end_pos, len, clip_len, y = b->cur_line;
-	unsigned char *p;
+	unsigned char *p = NULL;
 	clip_desc *cd, *new_cd;
 	line_desc *ld = b->cur_line_desc;
 
@@ -226,7 +224,7 @@ int copy_to_clip(buffer *b, int n, int cut) {
 
 					if (ld->line) memcpy(p, ld->line + start_pos, len);
 					p += len;
-					if (i != y) *(p++) = 0;
+					if (i != b->block_start_line) *(p++) = 0;
 				}
 				else clip_len += len + (i != y);
 
@@ -349,7 +347,7 @@ int paste_to_buffer(buffer *b, int n) {
 int copy_vert_to_clip(buffer *b, int n, int cut) {
 
 	int i, pass, start_pos, len, clip_len, y = b->cur_line, start_x, end_x;
-	char *p;
+	char *p = NULL;
 	clip_desc *cd, *new_cd;
 	line_desc *ld = b->cur_line_desc;
 
