@@ -1,24 +1,23 @@
 /* Display handling functions with optional update delay
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2010 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2011 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
-	This program is free software; you can redistribute it and/or modify it
-	under the terms of the GNU General Public License as published by the
-	Free Software Foundation; either version 2, or (at your option) any
-	later version.
-	
-	This program is distributed in the hope that it will be useful, but
-	WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-	General Public License for more details.
-	
-	You should have received a copy of the GNU General Public License along
-	with this program; see the file COPYING.  If not, write to the Free
-	Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-	02111-1307, USA. */
+	This library is free software; you can redistribute it and/or modify it
+	under the terms of the GNU General Public License as published by
+	the Free Software Foundation; either version 3 of the License, or (at your
+	option) any later version.
+
+	This library is distributed in the hope that it will be useful, but
+	WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+	or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+	for more details.
+
+	You should have received a copy of the GNU General Public License
+	along with this program; if not, see <http://www.gnu.org/licenses/>. */
+
 
 #include "ne.h"
 #include "cm.h"
@@ -284,7 +283,7 @@ line_desc *update_partial_line(buffer * const b, const int row, const int from_c
 /* Similar to the previous call, but updates the whole line. If the updated line is the current line,
 	we update the local attribute buffer. */
 
-void update_line(buffer * const b, const int n, const cleared_at_end, const int differential) {
+void update_line(buffer * const b, const int n, const int cleared_at_end, const int differential) {
 	line_desc * const ld = update_partial_line(b, n, 0, cleared_at_end, differential);
 	if (b->syn && ld == b->cur_line_desc) {
 		/* If we updated the entire current line, we update the local attribute buffer. */
@@ -376,7 +375,7 @@ void update_syntax_and_lines(buffer *b, line_desc *start_ld, line_desc *end_ld)
 	optimized (such as writing a space at the end of a line). TURBO is
 	taken into consideration. */
 
-void update_deleted_char(buffer * const b, const int c, const line_desc * const ld, int pos, int attr_pos, const int line, const int x) {
+void update_deleted_char(buffer * const b, const int c, const int a, const line_desc * const ld, int pos, int attr_pos, const int line, const int x) {
 
 	int i, j, c_width, tab_width, tab_found = FALSE, curr_attr_pos;
 
@@ -394,7 +393,7 @@ void update_deleted_char(buffer * const b, const int c, const line_desc * const
 		return;
 	}
 
-	if (pos > ld->line_len || (pos == ld->line_len && (c == '\t' || c == ' '))) return;
+	if (pos > ld->line_len || (pos == ld->line_len && ((c == '\t' || c == ' ') && !a))) return;
 
 	move_cursor(line, x);
 
@@ -732,3 +731,88 @@ HIGHLIGHT_STATE freeze_attributes(buffer *b, line_desc *ld) {
 	memcpy(b->attr_buf, attr_buf, (b->attr_len = attr_len) * sizeof *b->attr_buf);
 	return b->next_state;
 }
+
+/* (Un)highlights (depending on the value of show) the bracket matching
+the one under the cursor (if any). */
+
+void automatch_bracket(buffer * const b, const int show) {
+	static int c, orig_attr;
+	int match_pos, tmp_attr;
+	line_desc *matching_ld;
+	if (show) {
+		if (find_matching_bracket(b, b->win_y, b->win_y + ne_lines - 2 >= b->num_lines - 1 ? b->num_lines - 1 : b->win_y + ne_lines - 2,
+		                          &b->automatch.y, &match_pos, &c, &matching_ld) == OK) {
+			/* We limited find_matching_bracket()'s search to the visible lines, but not the
+			visible portions of those lines. Now ensure the matching pos is within the visible window. */
+			b->automatch.y -= b->win_y;
+			b->automatch.x = calc_width(matching_ld, match_pos, b->opt.tab_size, b->encoding) - b->win_x;
+			if (b->automatch.x >= 0 && b->automatch.x < ne_columns ) {
+				move_cursor(b->automatch.y, b->automatch.x);
+				if (b->syn) {
+					parse(b->syn, matching_ld, matching_ld->highlight_state, b->encoding == ENC_UTF8);
+					orig_attr = attr_buf[match_pos];
+				}
+				else orig_attr = 0; /* That's a stretch. FIX_ME */
+				tmp_attr = orig_attr;
+				if (b->opt.automatch & 1 ) { /* invert boldness of FG, BG */
+					switch (orig_attr & BG_MASK) {
+					case BG_BLACK:    tmp_attr = (tmp_attr & ~BG_MASK ) | BG_BBLACK;       break;
+					case BG_RED:      tmp_attr = (tmp_attr & ~BG_MASK ) | BG_BRED;         break;
+					case BG_GREEN:    tmp_attr = (tmp_attr & ~BG_MASK ) | BG_BGREEN;       break;
+					case BG_YELLOW:   tmp_attr = (tmp_attr & ~BG_MASK ) | BG_BYELLOW;      break;
+					case BG_BLUE:     tmp_attr = (tmp_attr & ~BG_MASK ) | BG_BBLUE;        break;
+					case BG_MAGENTA:  tmp_attr = (tmp_attr & ~BG_MASK ) | BG_BMAGENTA;     break;
+					case BG_CYAN:     tmp_attr = (tmp_attr & ~BG_MASK ) | BG_BCYAN;        break;
+					case BG_WHITE:    tmp_attr = (tmp_attr & ~BG_MASK ) | BG_BWHITE;       break;
+					case BG_BBLACK:   tmp_attr = (tmp_attr & ~BG_MASK ) | BG_BLACK;        break;
+					case BG_BRED:     tmp_attr = (tmp_attr & ~BG_MASK ) | BG_RED;          break;
+					case BG_BGREEN:   tmp_attr = (tmp_attr & ~BG_MASK ) | BG_GREEN;        break;
+					case BG_BYELLOW:  tmp_attr = (tmp_attr & ~BG_MASK ) | BG_YELLOW;       break;
+					case BG_BBLUE:    tmp_attr = (tmp_attr & ~BG_MASK ) | BG_BLUE;         break;
+					case BG_BMAGENTA: tmp_attr = (tmp_attr & ~BG_MASK ) | BG_MAGENTA;      break;
+					case BG_BCYAN:    tmp_attr = (tmp_attr & ~BG_MASK ) | BG_CYAN;         break;
+					case BG_BWHITE:   tmp_attr = (tmp_attr & ~BG_MASK ) | BG_WHITE;        break;
+					default:          tmp_attr = (tmp_attr & ~BG_MASK ) | BG_BWHITE;       break;
+					}                           
+					
+					switch (orig_attr & FG_MASK) {
+					case FG_BLACK:    tmp_attr = (tmp_attr & ~FG_MASK) | FG_BBLACK;      break;
+					case FG_RED:      tmp_attr = (tmp_attr & ~FG_MASK) | FG_BRED;        break;
+					case FG_GREEN:    tmp_attr = (tmp_attr & ~FG_MASK) | FG_BGREEN;      break;
+					case FG_YELLOW:   tmp_attr = (tmp_attr & ~FG_MASK) | FG_BYELLOW;     break;
+					case FG_BLUE:     tmp_attr = (tmp_attr & ~FG_MASK) | FG_BBLUE;       break;
+					case FG_MAGENTA:  tmp_attr = (tmp_attr & ~FG_MASK) | FG_BMAGENTA;    break;
+					case FG_CYAN:     tmp_attr = (tmp_attr & ~FG_MASK) | FG_BCYAN;       break;
+					case FG_WHITE:    tmp_attr = (tmp_attr & ~FG_MASK) | FG_BWHITE;      break;
+					case FG_BBLACK:   tmp_attr = (tmp_attr & ~FG_MASK) | FG_BLACK;       break;
+					case FG_BRED:     tmp_attr = (tmp_attr & ~FG_MASK) | FG_RED;         break;
+					case FG_BGREEN:   tmp_attr = (tmp_attr & ~FG_MASK) | FG_GREEN;       break;
+					case FG_BYELLOW:  tmp_attr = (tmp_attr & ~FG_MASK) | FG_YELLOW;      break;
+					case FG_BBLUE:    tmp_attr = (tmp_attr & ~FG_MASK) | FG_BLUE;        break;
+					case FG_BMAGENTA: tmp_attr = (tmp_attr & ~FG_MASK) | FG_MAGENTA;     break;
+					case FG_BCYAN:    tmp_attr = (tmp_attr & ~FG_MASK) | FG_CYAN;        break;
+					case FG_BWHITE:   tmp_attr = (tmp_attr & ~FG_MASK) | FG_WHITE;       break;
+					default:          tmp_attr = (tmp_attr & ~FG_MASK) | FG_BBLACK;      break;
+					}
+				}
+				if (b->opt.automatch & 2 ) {
+					tmp_attr = tmp_attr ^ INVERSE;
+				}
+				if (b->opt.automatch & 4 ) {
+					tmp_attr = tmp_attr ^ BOLD;
+				}
+				if (b->opt.automatch & 8 ) {
+					tmp_attr = tmp_attr ^ UNDERLINE;
+				}
+				output_char(c, tmp_attr, b->encoding == ENC_UTF8);
+				b->automatch.shown = 1;
+			}
+		}
+	} else {
+		if (b->automatch.shown) {
+			move_cursor(b->automatch.y, b->automatch.x);
+			output_char(c, orig_attr, b->encoding == ENC_UTF8);
+      	b->automatch.shown = 0;
+		}
+	}
+}
