@@ -1,25 +1,22 @@
 /* Various editing functions such as word wrap, to upper, etc.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna
-	Copyright (C) 1999-2010 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2011 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
-	This program is free software; you can redistribute it and/or modify it
-	under the terms of the GNU General Public License as published by the
-	Free Software Foundation; either version 2, or (at your option) any
-	later version.
+	This library is free software; you can redistribute it and/or modify it
+	under the terms of the GNU General Public License as published by
+	the Free Software Foundation; either version 3 of the License, or (at your
+	option) any later version.
 
-	This program is distributed in the hope that it will be useful, but
-	WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-	General Public License for more details.
-
-	You should have received a copy of the GNU General Public License along
-	with this program; see the file COPYING.  If not, write to the Free
-	Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-	02111-1307, USA.  */
+	This library is distributed in the hope that it will be useful, but
+	WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+	or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+	for more details.
 
+	You should have received a copy of the GNU General Public License
+	along with this program; if not, see <http://www.gnu.org/licenses/>.  */
 
 
 #include "ne.h"
@@ -43,7 +40,9 @@ static int to_something(buffer *b, int (to_first)(int), int (to_rest)(int)) {
 	if (b->cur_line == b->num_lines -1 && b->cur_pos >= b->cur_line_desc->line_len) return ERROR;
 
 	/* First of all, we search for the word start, if we're not over it. */
-	if (pos >= b->cur_line_desc->line_len || !ne_isword(c = get_char(&b->cur_line_desc->line[pos], b->encoding), b->encoding)) search_word(b, 1);
+	if (pos >= b->cur_line_desc->line_len || !ne_isword(c = get_char(&b->cur_line_desc->line[pos], b->encoding), b->encoding))
+		if (search_word(b, 1) != OK)
+			return ERROR;
 	x = b->cur_x; /* The original x position (to perform the line update). */
 
 	pos = b->cur_pos;
@@ -100,9 +99,7 @@ static int to_something(buffer *b, int (to_first)(int), int (to_rest)(int)) {
 		update_syntax_states(b, b->cur_y, b->cur_line_desc, NULL);
 	}
 
-	search_word(b, 1);
-
-	return OK;
+	return search_word(b, 1);
 }
 
 
@@ -132,6 +129,18 @@ int capitalize(buffer *b) {
 
 int match_bracket(buffer *b) {
 
+	int match_line, match_pos, rc;
+	rc = find_matching_bracket(b, 0, b->num_lines-1, &match_line, &match_pos, NULL, NULL);
+	if (rc == OK) {
+		goto_line(b, match_line);
+		goto_pos(b, match_pos);
+		return OK;
+	}	
+	return rc;
+}
+
+int find_matching_bracket(buffer *b, const int min_line, int max_line, int *match_line, int *match_pos, int *c, line_desc ** match_ld) {
+
 	static unsigned char bracket_table[NUM_BRACKETS][2] = { { '(',')' }, { '[',']' }, { '{','}' }, { '<','>' } };
 
 	int i, j, n, y, dir, pos;
@@ -155,7 +164,7 @@ int match_bracket(buffer *b) {
 	pos = b->cur_pos;
 	y = b->cur_line;
 
-	while(ld->ld_node.next && ld->ld_node.prev) {
+	while(ld->ld_node.next && ld->ld_node.prev && y >= min_line && y <= max_line) {
 
 		if (pos >= 0) {
 			line = ld->line;
@@ -165,8 +174,10 @@ int match_bracket(buffer *b) {
 				else if (line[pos] == bracket_table[i][1 - j]) n--;
 
 				if (n == 0) {
-					goto_line(b, y);
-					goto_pos(b, pos);
+					*match_line = y;
+					*match_pos  = pos;
+					if (c) *c = line[pos];
+					if (match_ld) *match_ld = ld;
 					return OK;
 				}
 				if (dir > 0) pos = next_pos(line, pos, b->encoding);
