@@ -1,24 +1,22 @@
 /* Error message vector.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2010 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2011 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
-	This program is free software; you can redistribute it and/or modify it
-	under the terms of the GNU General Public License as published by the
-	Free Software Foundation; either version 2, or (at your option) any
-	later version.
-	
-	This program is distributed in the hope that it will be useful, but
-	WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-	General Public License for more details.
-	
-	You should have received a copy of the GNU General Public License along
-	with this program; see the file COPYING.  If not, write to the Free
-	Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-	02111-1307, USA.  */
+	This library is free software; you can redistribute it and/or modify it
+	under the terms of the GNU General Public License as published by
+	the Free Software Foundation; either version 3 of the License, or (at your
+	option) any later version.
+
+	This library is distributed in the hope that it will be useful, but
+	WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+	or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+	for more details.
+
+	You should have received a copy of the GNU General Public License
+	along with this program; if not, see <http://www.gnu.org/licenses/>.  */
 
 
 #include "errors.h"
@@ -34,11 +32,15 @@ char *error_msg[ERROR_COUNT] = {
 	"You are not positioned over {}, (), [] or <>.",
 	"Can't find matching bracket.",
 	"Bookmark not set.",
-	"Bookmark number out of range.",
+	"Invalid Bookmark designation (use 0 through 9, -1, +1, or '-').",
+	"No unset Bookmarks to set.",
+	"No set Bookmarks to goto.",
+	"No set Bookmarks to unset.",
 	"You cannot insert a character whose ASCII code is 0.",
 	"No search string.",
 	"No replace string.",
 	"TAB size out of range.",
+	"Invalid match mode.",
 	"Mark a block first.",
 	"Out of memory. DANGER!",
 	"Nothing to undo.",
@@ -61,6 +63,7 @@ char *error_msg[ERROR_COUNT] = {
 	"This file is read-only.",
 	"Can't open file (file is migrated).",
 	"Can't open file (file is a directory).",
+	"Can't open file (file is too large).",
 	"Stopped.",
 	"I/O error.",
 	"The argument string is empty.",
