@@ -1,31 +1,30 @@
 /* Help string externs.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2010 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2011 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
-	This program is free software; you can redistribute it and/or modify it
-	under the terms of the GNU General Public License as published by the
-	Free Software Foundation; either version 2, or (at your option) any
-	later version.
-	
-	This program is distributed in the hope that it will be useful, but
-	WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-	General Public License for more details.
-	
-	You should have received a copy of the GNU General Public License along
-	with this program; see the file COPYING.  If not, write to the Free
-	Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-	02111-1307, USA.  */
+	This library is free software; you can redistribute it and/or modify it
+	under the terms of the GNU General Public License as published by
+	the Free Software Foundation; either version 3 of the License, or (at your
+	option) any later version.
+
+	This library is distributed in the hope that it will be useful, but
+	WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+	or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+	for more details.
+
+	You should have received a copy of the GNU General Public License
+	along with this program; if not, see <http://www.gnu.org/licenses/>.  */
 
 
-extern const char * const ABOUT_HELP[ 5 ];
+extern const char * const ABOUT_HELP[ 7 ];
 extern const char * const ADJUSTVIEW_HELP[ 26 ];
 extern const char * const ALERT_HELP[ 5 ];
 extern const char * const AUTOCOMPLETE_HELP[ 20 ];
 extern const char * const AUTOINDENT_HELP[ 22 ];
+extern const char * const AUTOMATCHBRACKET_HELP[ 11 ];
 extern const char * const AUTOPREFS_HELP[ 14 ];
 extern const char * const BACKSPACE_HELP[ 6 ];
 extern const char * const BEEP_HELP[ 6 ];
@@ -53,10 +52,10 @@ extern const char * const EXIT_HELP[ 6 ];
 extern const char * const FASTGUI_HELP[ 19 ];
 extern const char * const FIND_HELP[ 12 ];
 extern const char * const FINDREGEXP_HELP[ 12 ];
-extern const char * const FLAGS_HELP[ 30 ];
+extern const char * const FLAGS_HELP[ 32 ];
 extern const char * const FLASH_HELP[ 6 ];
 extern const char * const FREEFORM_HELP[ 18 ];
-extern const char * const GOTOBOOKMARK_HELP[ 13 ];
+extern const char * const GOTOBOOKMARK_HELP[ 15 ];
 extern const char * const GOTOCOLUMN_HELP[ 8 ];
 extern const char * const GOTOLINE_HELP[ 10 ];
 extern const char * const GOTOMARK_HELP[ 9 ];
@@ -130,7 +129,7 @@ extern const char * const SAVEMACRO_HELP[ 20 ];
 extern const char * const SAVEPREFS_HELP[ 11 ];
 extern const char * const SEARCHBACK_HELP[ 14 ];
 extern const char * const SELECTDOC_HELP[ 14 ];
-extern const char * const SETBOOKMARK_HELP[ 10 ];
+extern const char * const SETBOOKMARK_HELP[ 12 ];
 extern const char * const STATUSBAR_HELP[ 23 ];
 extern const char * const SUSPEND_HELP[ 6 ];
 extern const char * const SYNTAX_HELP[ 42 ];
@@ -146,7 +145,7 @@ extern const char * const TURBO_HELP[ 29 ];
 extern const char * const UNDELLINE_HELP[ 15 ];
 extern const char * const UNDO_HELP[ 9 ];
 extern const char * const UNLOADMACROS_HELP[ 12 ];
-extern const char * const UNSETBOOKMARK_HELP[ 10 ];
+extern const char * const UNSETBOOKMARK_HELP[ 11 ];
 extern const char * const UTF8_HELP[ 20 ];
 extern const char * const UTF8AUTO_HELP[ 14 ];
 extern const char * const UTF8IO_HELP[ 13 ];
