@@ -1,24 +1,22 @@
 /* Terminfo database scanning and keyboard escape sequence matching functions.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2010 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2011 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
-	This program is free software; you can redistribute it and/or modify it
-	under the terms of the GNU General Public License as published by the
-	Free Software Foundation; either version 2, or (at your option) any
-	later version.
-	
-	This program is distributed in the hope that it will be useful, but
-	WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-	General Public License for more details.
-	
-	You should have received a copy of the GNU General Public License along
-	with this program; see the file COPYING.  If not, write to the Free
-	Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-	02111-1307, USA.  */
+	This library is free software; you can redistribute it and/or modify it
+	under the terms of the GNU General Public License as published by
+	the Free Software Foundation; either version 3 of the License, or (at your
+	option) any later version.
+
+	This library is distributed in the hope that it will be useful, but
+	WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+	or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+	for more details.
+
+	You should have received a copy of the GNU General Public License
+	along with this program; if not, see <http://www.gnu.org/licenses/>.  */
 
 
 #include "ne.h"
@@ -28,7 +26,8 @@
 #include <string.h>
 
 
-/* Maximum number of key definitions from terminfo */
+/* Maximum number of key definitions from terminfo plus others
+   we may get from keys file -- i.e. key_may_set(). */
 
 #define MAX_TERM_KEY 512
 
@@ -125,19 +124,25 @@ assigned. It assumes the array is already sorted, and it keeps it
 that way. This is part of the horrible hack to make cursor and
 function keys work on numerous terminals which have broken terminfo
 and termcap entries, or for weak terminal emulators which happen to
-produce well-known sequences. */
+produce well-known sequences. Returns
+   > 0 on success,
+   ==0 if table is full (or no cap_string supplied)
+   < 0 if string is already defined.
+ */
 
 
-static void key_may_set(const char * const cap_string, const int code) {
-	int pos;
+int key_may_set(const char * const cap_string, const int code) {
+	int pos=0;
 
-	if (!cap_string || (pos = binsearch(cap_string)) < 0) return;
+   if (num_keys >= MAX_TERM_KEY - 1) return 0;
+	if (!cap_string || (pos = binsearch(cap_string)) < 0) return pos;
 
 	memmove(key + pos + 1, key + pos, (num_keys - pos) * sizeof *key);
 	key[pos].string = (unsigned char *)cap_string;
 	key[pos].code = code;
 	num_keys++;
-	assert(num_keys < MAX_TERM_KEY - 1);
+	assert(num_keys < MAX_TERM_KEY);
+	return pos+1;
 }
 
 
@@ -521,7 +526,7 @@ int get_key_code(void) {
 		errno = 0;
 		c = getchar();
 		e = errno;
-		
+
 		if (partial_match) set_termios_timeout(0);
 
 		/* This is necessary to circumvent the slightly different behaviour of getc() in Linux and BSD. */
@@ -537,9 +542,9 @@ int get_key_code(void) {
 		else {
 			if (cur_len) {
 
-				/* We ran out of time. If our match was not UTF-8, then the current
-					we return the first character of the keyboard buffer is returned. 
-					Otherwise, we discard the partially received UTF-8 sequence. */
+				/* We ran out of time. If our match was UTF-8, we discard the
+					partially received UTF-8 sequence. Otherwise, we return the
+					first character of the keyboard buffer.  */
 
 				if (partial_is_utf8) cur_len = last_match = partial_is_utf8 = 0;
 				else {
@@ -548,6 +553,7 @@ int get_key_code(void) {
 					return c;
 				}
 			}
+			else return INVALID_CHAR;
 		}
 	}
 }
