@@ -1,24 +1,22 @@
 /* Menu handling function. Includes also key and menu configuration parsing.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna
-	Copyright (C) 1999-2010 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2011 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
-	This program is free software; you can redistribute it and/or modify it
-	under the terms of the GNU General Public License as published by the
-	Free Software Foundation; either version 2, or (at your option) any
-	later version.
-	
-	This program is distributed in the hope that it will be useful, but
-	WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-	General Public License for more details.
-	
-	You should have received a copy of the GNU General Public License along
-	with this program; see the file COPYING.  If not, write to the Free
-	Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-	02111-1307, USA.  */
+	This library is free software; you can redistribute it and/or modify it
+	under the terms of the GNU General Public License as published by
+	the Free Software Foundation; either version 3 of the License, or (at your
+	option) any later version.
+
+	This library is distributed in the hope that it will be useful, but
+	WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+	or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+	for more details.
+
+	You should have received a copy of the GNU General Public License
+	along with this program; if not, see <http://www.gnu.org/licenses/>.  */
 
 
 #include "ne.h"
@@ -59,6 +57,7 @@
 #define MENU_KEYWORD "MENU"
 #define ITEM_KEYWORD "ITEM"
 #define KEY_KEYWORD "KEY"
+#define SEQ_KEYWORD "SEQ"
 
 
 /* This structure defines a menu item. command_line points to
@@ -335,7 +334,7 @@ int dump_config(void) {
 #endif
 
 static void draw_cur_item(const int n) {
-	move_cursor(menus[n].cur_item + 1, menus[n].xpos);
+	move_cursor(menus[n].cur_item + 1, menus[n].xpos - (fast_gui || !standout_ok));
 	if (!fast_gui && standout_ok) output_chars(menus[n].items[menus[n].cur_item].text, NULL, menus[n].width - (cursor_on_off_ok ? 0 : 1), TRUE);
 }
 
@@ -344,7 +343,7 @@ static void undraw_cur_item(const int n) {
 	if (!fast_gui && standout_ok)  {
 		set_attr(0);
 		standout_on();
-		move_cursor(1 + menus[n].cur_item, menus[n].xpos);
+		move_cursor(menus[n].cur_item + 1, menus[n].xpos);
 		output_chars(menus[n].items[menus[n].cur_item].text, NULL, menus[n].width - (cursor_on_off_ok ? 0 : 1), TRUE);
 		standout_off();
 	}
@@ -1042,7 +1041,7 @@ static void get_key_bind(const char * key_bindings_name, char * (exists_prefs_fu
 		if (key_bindings = malloc(strlen(prefs_dir) + strlen(key_bindings_name) + 1)) {
 			strcat(strcpy(key_bindings, prefs_dir), key_bindings_name);
 
-			if ((cs = load_stream(NULL, key_bindings_name, FALSE, FALSE)) || (cs = load_stream(NULL, key_bindings, FALSE, FALSE))) {
+			if (cs = load_stream(NULL, key_bindings, FALSE, FALSE)) {
 
 				p = cs->stream;
 				line = 1;
@@ -1066,7 +1065,29 @@ static void get_key_bind(const char * key_bindings_name, char * (exists_prefs_fu
 						}
 						else error_in_key_bindings(line, "can't read key code.");
 					}
-
+					else if (*p && !cmdcmp(SEQ_KEYWORD, p)) {
+						char *buf;
+						while(*p && !isasciispace(*p)) p++;    /* skip past SEQ */
+						while(isasciispace(*p)) p++;           /* skip to quoted sequence, like  "\x1b[A" */
+						buf = p;   /* Risky: we're replacing the double-quoted string with its parsed equivalent in situ. */
+						if (parse_string(&p, buf, strlen(p)) > 0) {  /* parse_string() expects double-quoted string. */
+							while(*p && isasciispace(*p)) p++;  /* skip to key code */
+							if (*p && sscanf(p, "%x %*s", &c) == 1) {    /* convert key code */
+								if (c >= 0 && c < NUM_KEYS) {
+									if (c != 27 && c != 13) {
+										if ((c=key_may_set(buf,c)) < 0)
+											error_in_key_bindings(line, "sequence already assigned." );
+										else if (c==0)
+											error_in_key_bindings(line, "sequence table full." );
+									}
+									else error_in_key_bindings(line, "you cannot redefine ESCAPE and RETURN.");
+								}
+								else error_in_key_bindings(line, "key code out of range.");
+							}
+							else error_in_key_bindings(line, "can't read key code.");
+						}
+						else error_in_key_bindings(line, "can't read double quoted character sequence.");
+					}
 					line++;
 					p += strlen(p) + 1;
 				}
@@ -1077,10 +1098,17 @@ static void get_key_bind(const char * key_bindings_name, char * (exists_prefs_fu
 	}
 }
 
+char *cur_dir(void) {
+	static char *cur_dir = "./";
+	return cur_dir;
+}
+
 /* Key bindings override easily, so pull in any global bindings
    first, then override with the users bindings. */
 void get_key_bindings(const char * key_bindings_name) {
 	get_key_bind(key_bindings_name, exists_gprefs_dir);
 	get_key_bind(key_bindings_name, exists_prefs_dir);
+	get_key_bind(key_bindings_name, cur_dir);
 }
 
+
