@@ -1,24 +1,22 @@
 /* main(), global initialization and global buffer functions.
 
-	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2010 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1993-1998 Sebastiano Vigna
+	Copyright (C) 1999-2011 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
-	This program is free software; you can redistribute it and/or modify it
-	under the terms of the GNU General Public License as published by the
-	Free Software Foundation; either version 2, or (at your option) any
-	later version.
-	
-	This program is distributed in the hope that it will be useful, but
-	WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-	General Public License for more details.
-	
-	You should have received a copy of the GNU General Public License along
-	with this program; see the file COPYING.  If not, write to the Free
-	Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-	02111-1307, USA.  */
+	This library is free software; you can redistribute it and/or modify it
+	under the terms of the GNU General Public License as published by
+	the Free Software Foundation; either version 3 of the License, or (at your
+	option) any later version.
+
+	This library is distributed in the hope that it will be useful, but
+	WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+	or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+	for more details.
+
+	You should have received a copy of the GNU General Public License
+	along with this program; if not, see <http://www.gnu.org/licenses/>.  */
 
 
 #include "regex.h"
@@ -38,22 +36,28 @@ message disappears as soon as any key is typed. */
 
 char *NO_WARRANTY_msg[] = {	PROGRAM_NAME " " VERSION ".",
 										"Copyright (C) 1993-1998 Sebastiano Vigna",
-										"Copyright (C) 1999-2010 Todd M. Lewis and Sebastiano Vigna",
+										"Copyright (C) 1999-2011 Todd M. Lewis and Sebastiano Vigna",
 										"",
 										"This program is free software; you can redistribute it and/or modify",
 										"it under the terms of the GNU General Public License as published by",
-										"the Free Software Foundation; either version 2, or (at your option)",
-										"any later version.",
+										"the Free Software Foundation; either version 3 of the License, or (at your",
+										"option) any later version.",
 										"",
-										"This program is distributed in the hope that it will be useful,",
-										"but WITHOUT ANY WARRANTY; without even the implied warranty of",
-										"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the",
-										"GNU General Public License for more details.",
+										"This program is distributed in the hope that it will be useful, but",
+										"WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY",
+										"or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License",
+										"for more details.",
+										"",
+										"You should have received a copy of the GNU General Public License",
+										"along with this program; if not, see <http://www.gnu.org/licenses/>.",
 										"",
 										"Press F1, Escape or Escape-Escape to see the menus. The shortcuts",
 										"prefixed by ^ are activated by the Control key; the shortcuts prefixed",
 										"by [ are activated by Control+Meta or just Meta, depending on your terminal",
 										"emulator. Alternatively, just press Escape followed by a letter.",
+										"",
+										"ne Home page: http://ne.dsi.unimi.it/",
+										"Discuss ne at http://groups.google.com/group/niceeditor/",
 										NULL
 									};
 
@@ -61,8 +65,9 @@ char *NO_WARRANTY_msg[] = {	PROGRAM_NAME " " VERSION ".",
 char ARG_HELP[] = ABOUT_MSG "\n"
 						"Usage: ne [options] [files]\n"
 						"--help        print this message.\n"
-						"--            next token is a filename.\n"
-						"+[N]          move to the N-th (or the last, if N is missing) line of the first file.\n"
+						"--           *next token is a filename.\n"
+						"+[N[,M]]     *move to last or N-th line, first or M-th column of next named file.\n"
+						"--binary     *load the next file in binary mode.\n"
 						"--utf8        use UTF-8 I/O.\n"
 						"--no-utf8     do not use UTF-8 I/O.\n"
 						"--ansi        use built-in ANSI control sequences.\n"
@@ -71,7 +76,8 @@ char ARG_HELP[] = ABOUT_MSG "\n"
 						"--no-syntax   disable syntax-highlighting support.\n"
 						"--keys FILE   use this file for keyboard configuration.\n"
 						"--menus FILE  use this file for menu configuration.\n"
-						"--macro FILE  exec this macro after start.\n";
+						"--macro FILE  exec this macro after start.\n\n"
+						"             *These options may appear multiple times.\n";
 
 
 /* The regular expression used to parse the locale. */
@@ -86,7 +92,7 @@ list clips = { (node *)&clips.tail, NULL, (node *)&clips.head };
 list macros = { (node *)&macros.tail, NULL, (node *)&macros.head };
 
 /* global prefs, only saved in ~/.ne/.default#ap if their
-   current setting differs from these defaults. Make sure these
+   current settings differ from these defaults. Make sure these
    defaults match the conditionals in prefs.c:save_prefs(). */
 int req_order;
 int fast_gui;
@@ -108,13 +114,13 @@ buffer *new_buffer(void) {
 
 	if (b) {
 		clear_buffer(b);
-		if (cur_buffer) 
+		if (cur_buffer)
 			add(&b->b_node, &cur_buffer->b_node);
-		else 
+		else
 			add_head(&buffers, &b->b_node);
-		
-		
-		
+
+
+
 		cur_buffer = b;
 	}
 
@@ -141,14 +147,43 @@ int delete_buffer(void) {
 	return FALSE;
 }
 
+void about(int show) {
+   int i;
 
+   if (show) {
+		clear_entire_screen();
+		for(i = 0; NO_WARRANTY_msg[i]; i++) {
+			if (i == ne_lines - 1) break;
+			move_cursor(i, 0);
+			output_string(NO_WARRANTY_msg[i], FALSE);
+		}
+		if (++i < ne_lines - 1) {
+			move_cursor(i, 0);
+			if (exists_gprefs_dir()) {
+				output_string("Global Directory: ", FALSE);
+				output_string(exists_gprefs_dir(), FALSE);
+			}
+			else {
+				output_string("Global directory \"", FALSE);
+				output_string(get_global_dir(), FALSE);
+				output_string("\" not found!", FALSE);
+			}
+		}
+		print_message(ABOUT_MSG);
+	}
+	else {
+      ttysize();
+      keep_cursor_on_screen(cur_buffer);
+      reset_window();
+	}
+}
 
 /* The main() function. It is responsible for argument parsing, calling
 some terminal and signal initialization functions, and entering the
 event loop. */
 
 int main(int argc, char **argv) {
-	
+
 	input_class ic;
 	int i, c, no_config = FALSE, displaying_info = FALSE, first_line = 0;
 	char *macro_name = NULL, *key_bindings_name = NULL, *menu_conf_name = NULL;
@@ -185,7 +220,7 @@ int main(int argc, char **argv) {
 		N-th line. */
 
 		if (argv[i][0] == '-' && argv[i][1] == '-') {
-			if (!argv[i][2]) skiplist[i++] = 1; /* You can use "--" to force the next token to be a filename */
+			if (!argv[i][2]) i++; /* You can use "--" to force the next token to be a filename */
 			else if (!strcmp(&argv[i][2], "help" "\0" VERSION_STRING)) {
 				puts(ARG_HELP);
 				exit(0);
@@ -233,11 +268,6 @@ int main(int argc, char **argv) {
 				}
 			}
 		}
-		else if (argv[i][0] == '+') {
-			first_line = argv[i][1] ? strtol(argv[i]+1, NULL, 10) : INT_MAX;
-			if (errno || first_line < 0) first_line = 0;
-			skiplist[i] = 1; /* argv[i] = NULL; */
-		}
 	}
 
 #ifdef NE_TEST
@@ -310,15 +340,56 @@ int main(int argc, char **argv) {
 		unwanted results). */
 
 		int first_file = TRUE;
-
+		int first_line=0, first_col=0, binary=0, skip_plus=0;
+      char *d;
 		stop = FALSE;
 
 		for(i = 1; i < argc && !stop; i++) {
 			if (argv[i] && !skiplist[i]) {
-				if (!first_file) do_action(cur_buffer, NEWDOC_A, -1, NULL);
-				else first_file = FALSE;
-
-				do_action(cur_buffer, OPEN_A, 0, str_dup(argv[i]));
+				if (argv[i][0] == '+' && !skip_plus) {   /* looking for "+", or "+N" or "+N,M"  */
+					int tmp_l=INT_MAX, tmp_c=0;
+					char *d;
+					errno = 0;
+					if (argv[i][1]) {
+						if (isdigit(argv[i][1])) {
+							tmp_l = strtol(argv[i]+1, &d, 10);
+							if (!errno) {
+								if (*d) {                     /* separator between N and M */
+									if (isdigit(d[1])) {
+										tmp_c = strtol(d+1, &d, 10);
+										if (*d) errno = ERANGE;
+									}
+									else errno = ERANGE;
+								}
+							}
+						}
+						else errno = ERANGE;
+					}
+					if (!errno) {
+						first_line = tmp_l;
+						first_col  = tmp_c;
+					}
+					else {
+						skip_plus = 1;
+						i--;
+					}
+				}
+				else if (!strcmp(argv[i],"--binary")) {
+					binary = 1;
+				}
+				else {
+					if (!strcmp(argv[i],"--")) i++;
+					if (!first_file) do_action(cur_buffer, NEWDOC_A, -1, NULL);
+					else first_file = FALSE;
+               cur_buffer->opt.binary = binary;
+               if (i<argc) do_action(cur_buffer, OPEN_A, 0, str_dup(argv[i]));
+					if (first_line) do_action(cur_buffer, GOTOLINE_A, first_line, NULL);
+					if (first_col)  do_action(cur_buffer, GOTOCOLUMN_A, first_col, NULL);
+					skip_plus  =
+					first_line =
+					first_col  =
+					binary     = 0;
+				}
 			}
 		}
 
@@ -328,7 +399,7 @@ int main(int argc, char **argv) {
 		only if more than one buffer exist. */
 
 		if (get_nth_buffer(1)) do_action(cur_buffer, NEXTDOC_A, -1, NULL);
-		if (first_line) do_action(cur_buffer, GOTOLINE_A, first_line, NULL);
+		
 	}
 
 	/* Note that we do not need to update the display. clear_entire_screen() is
@@ -342,25 +413,9 @@ int main(int argc, char **argv) {
 		/* If there is no file to load, and no macro to execute, we display
 		the "NO WARRANTY" message. */
 
-		displaying_info = TRUE;
+      about(1);
+      displaying_info = TRUE;
 
-		for(i = 0; NO_WARRANTY_msg[i]; i++) {
-			if (i == ne_lines - 1) break;
-			move_cursor(i, 0);
-			output_string(NO_WARRANTY_msg[i], FALSE);
-		}
-		if (++i < ne_lines - 1) {
-			move_cursor(i, 0);
-			if (exists_gprefs_dir()) {
-				output_string("Global Directory: ", FALSE);
-				output_string(exists_gprefs_dir(), FALSE);
-			}
-			else {
-				output_string("Global directory \"", FALSE);
-				output_string(get_global_dir(), FALSE);
-				output_string("\" not found!", FALSE);
-			}
-		}
 	}
 
 	while(TRUE) {
@@ -368,37 +423,36 @@ int main(int argc, char **argv) {
 		/* If we are displaying the "NO WARRANTY" info, we should not refresh the
 		window now */
 
-		if (!displaying_info) refresh_window(cur_buffer);
-	
-		draw_status_bar();
+		if (!displaying_info) {
+			refresh_window(cur_buffer);
+			if (cur_buffer->opt.automatch) automatch_bracket(cur_buffer, TRUE);
+		}
 
+		draw_status_bar();
 		move_cursor(cur_buffer->cur_y, cur_buffer->cur_x);
 
 		c = get_key_code();
-		ic = CHAR_CLASS(c);
 
 		if (window_changed_size) {
 			print_error(do_action(cur_buffer, REFRESH_A, 0, NULL));
 			window_changed_size = FALSE;
+			cur_buffer->automatch.shown = 0;
 		}
 
+		if ( c == INVALID_CHAR ) continue; // Window resizing.
+		ic = CHAR_CLASS(c);
+
 		if (displaying_info) {
+			about(0);
 			displaying_info = FALSE;
-
-			for(i = 0; i < sizeof NO_WARRANTY_msg / sizeof *NO_WARRANTY_msg + 2; i++) {
-				if (i == ne_lines - 1) break;
-				move_cursor(i, 0);
-				clear_to_eol();
-			}
-
-			fflush(stdout);
 		}
+		else if (cur_buffer->automatch.shown) automatch_bracket(cur_buffer, FALSE);
 
 		switch(ic) {
 		case INVALID:
 			print_error(INVALID_CHARACTER);
 			break;
-			
+
 		case ALPHA:
 			print_error(do_action(cur_buffer, INSERTCHAR_A, c, NULL));
 			break;
@@ -406,7 +460,7 @@ int main(int argc, char **argv) {
 		case TAB:
 			print_error(do_action(cur_buffer, INSERTTAB_A, 1, NULL));
 			break;
-			
+
 		case RETURN:
 			print_error(do_action(cur_buffer, INSERTLINE_A, -1, NULL));
 			break;
@@ -415,7 +469,7 @@ int main(int argc, char **argv) {
 			if (c < 0) c = -c - 1;
 			if (key_binding[c]) print_error(execute_command_line(cur_buffer, key_binding[c]));
 			break;
-			
+
 		default:
 			break;
 		}
