@@ -1,24 +1,23 @@
 /* Function prototypes
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2010 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2011 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
-	This program is free software; you can redistribute it and/or modify it
-	under the terms of the GNU General Public License as published by the
-	Free Software Foundation; either version 2, or (at your option) any
-	later version.
-	
-	This program is distributed in the hope that it will be useful, but
-	WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-	General Public License for more details.
-	
-	You should have received a copy of the GNU General Public License along
-	with this program; see the file COPYING.  If not, write to the Free
-	Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-	02111-1307, USA.  */
+	This library is free software; you can redistribute it and/or modify it
+	under the terms of the GNU General Public License as published by
+	the Free Software Foundation; either version 3 of the License, or (at your
+	option) any later version.
+
+	This library is distributed in the hope that it will be useful, but
+	WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+	or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+	for more details.
+
+	You should have received a copy of the GNU General Public License
+	along with this program; if not, see <http://www.gnu.org/licenses/>.  */
+
 
 /* actions.c */
 int do_action(buffer *b, action a, int c, unsigned char *p);
@@ -106,19 +105,21 @@ void update_line(buffer *b, int n, const int cleared_at_end, const int different
 void update_window_lines(buffer *b, int start_line, int end_line, int doit);
 void update_syntax_and_lines(buffer *b, line_desc *start_ld, line_desc *end_ld);
 void update_window(buffer *b);
-void update_deleted_char(buffer *b, int c, const line_desc *ld, int pos, int attr_pos, int line, int x);
+void update_deleted_char(buffer *b, int c, int a, const line_desc *ld, int pos, int attr_pos, int line, int x);
 void update_inserted_char(buffer *b, int c, const line_desc *ld, int pos, int attr_pos, int line, int x);
 void update_overwritten_char(buffer *b, int old_char, int new_char, const line_desc *ld, int pos, int attr_pos, int line, int x);
 void reset_window(void);
 void refresh_window(buffer *b);
 void scroll_window(buffer *b, int line, int n);
 HIGHLIGHT_STATE freeze_attributes(buffer *b, line_desc *ld);
+void automatch_bracket(buffer * const b, const int show);
 
 /* edit.c */
 int to_upper(buffer *b);
 int to_lower(buffer *b);
 int capitalize(buffer *b);
 int match_bracket(buffer *b);
+int find_matching_bracket(buffer *b, const int min_line, const int max_line, int *match_line, int *match_pos, int *c, line_desc ** ld);
 int word_wrap(buffer *b);
 int paragraph(buffer *b);
 int center(buffer *b);
@@ -147,6 +148,7 @@ const char *ext2syntax(const char * const ext);
 void read_key_capabilities(void);
 void set_escape_time(int new_escape_time);
 int get_key_code(void);
+int key_may_set(const char * const cap_string, const int code);
 
 /* menu.c */
 void print_message(const char *message);
@@ -196,6 +198,8 @@ void move_inc_up(buffer *b);
 /* ne.c */
 buffer *new_buffer(void);
 int delete_buffer(void);
+void about(int show);
+void automatch_bracket(buffer *b, int show);
 int main(int argc, char **argv);
 
 /* prefs.c */
@@ -225,7 +229,7 @@ char *request_file(const buffer *b, const char *prompt, const char *default_name
 int   request_document(void);
 
 /* search.c */
-int  find(buffer *b, const unsigned char *pattern, const skip_first);
+int  find(buffer *b, const unsigned char *pattern, const int skip_first);
 int  replace(buffer *b, int n, const char *string);
 int  find_regexp(buffer *b, const unsigned char *regex, const int skip_first);
 int  replace_regexp(buffer *b, const char *string);
