@@ -1,24 +1,23 @@
 /* Signal handling setup and code.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2010 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2011 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
-	This program is free software; you can redistribute it and/or modify it
-	under the terms of the GNU General Public License as published by the
-	Free Software Foundation; either version 2, or (at your option) any
-	later version.
-	
-	This program is distributed in the hope that it will be useful, but
-	WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-	General Public License for more details.
-	
-	You should have received a copy of the GNU General Public License along
-	with this program; see the file COPYING.  If not, write to the Free
-	Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-	02111-1307, USA.  */
+	This library is free software; you can redistribute it and/or modify it
+	under the terms of the GNU General Public License as published by
+	the Free Software Foundation; either version 3 of the License, or (at your
+	option) any later version.
+
+	This library is distributed in the hope that it will be useful, but
+	WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+	or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+	for more details.
+
+	You should have received a copy of the GNU General Public License
+	along with this program; if not, see <http://www.gnu.org/licenses/>.  */
+
 
 #include "ne.h"
 #include <signal.h>
@@ -57,21 +56,14 @@ static void fatal_code(const int sig) {
 }
 
 
-/* The next two functions handle the suspend/restart system. When stopped,
+/* The next function handles the suspend/restart system. When stopped,
 we reset the terminal status, set up the continuation handler and let the
 system stop us by sending again a TSTP signal, this time using the default
-handler. When we get a CONT signal, we set the terminal, set up the stop
-handler and reset the screen. */
-
-/*static void cont_code(int sig) {
-
-	set_interactive_mode();
-	ttysize();
-	}*/
+handler. */
 
 void stop_ne(void) {
 	unset_interactive_mode();
-	kill(getpid(), SIGTSTP);
+	kill(0, SIGTSTP);
 	set_interactive_mode();
 	clear_entire_screen();
 	ttysize();
@@ -79,7 +71,6 @@ void stop_ne(void) {
 }
 
 
-
 /* This mask will hold all the existing signals. */
 
 static sigset_t signal_full_mask;
