@@ -1,25 +1,22 @@
 /* Stream handling functions.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2010 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2011 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
-	This program is free software; you can redistribute it and/or modify it
-	under the terms of the GNU General Public License as published by the
-	Free Software Foundation; either version 2, or (at your option) any
-	later version.
-	
-	This program is distributed in the hope that it will be useful, but
-	WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-	General Public License for more details.
-	
-	You should have received a copy of the GNU General Public License along
-	with this program; see the file COPYING.  If not, write to the Free
-	Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-	02111-1307, USA.  */
+	This library is free software; you can redistribute it and/or modify it
+	under the terms of the GNU General Public License as published by
+	the Free Software Foundation; either version 3 of the License, or (at your
+	option) any later version.
 
+	This library is distributed in the hope that it will be useful, but
+	WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+	or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+	for more details.
+
+	You should have received a copy of the GNU General Public License
+	along with this program; if not, see <http://www.gnu.org/licenses/>.  */
 
 
 #include "ne.h"
@@ -196,7 +193,7 @@ char_stream *load_stream(char_stream * cs, const char *name, const int preserve_
 
 	name = tilde_expand(name);
 
-	if (is_migrated(name) || is_directory(name)) return NULL;
+	if (is_directory(name) || is_migrated(name)) return NULL;
 
 	cs = load_stream_from_fh(cs, fh = open(name, READ_FLAGS), preserve_cr, binary);
 	if (fh >= 0) close(fh);
@@ -268,8 +265,8 @@ int save_stream(const char_stream *const cs, const char *name, const int CRLF, c
 
 	name = tilde_expand(name);
 
-	if (is_migrated(name)) return  FILE_IS_MIGRATED ;
 	if (is_directory(name)) return  FILE_IS_DIRECTORY ;
+	if (is_migrated(name)) return  FILE_IS_MIGRATED ;
 
 	if ((fh = open(name, WRITE_FLAGS, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH))>=0) {
 		error = save_stream_to_fh(cs, fh, CRLF, binary);
