@@ -1,10 +1,24 @@
-/*
- *	Copyright
- *		(C) 2004 Joseph H. Allen
- *
- *	This file is part of JOE (Joe's Own Editor)
- */
- 
+/* Syntax highlighting from Joe's Own Editor: Types
+
+	Copyright (C) 2004 Joseph H. Allen
+	Copyright (C) 2009-2011 Todd M. Lewis and Sebastiano Vigna
+
+	This file is part of ne, the nice editor.
+
+	This library is free software; you can redistribute it and/or modify it
+	under the terms of the GNU General Public License as published by
+	the Free Software Foundation; either version 3 of the License, or (at your
+	option) any later version.
+
+	This library is distributed in the hope that it will be useful, but
+	WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+	or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+	for more details.
+
+	You should have received a copy of the GNU General Public License
+	along with this program; if not, see <http://www.gnu.org/licenses/>.  */
+
+
 #include <string.h>
 #include <errno.h>
 #include <math.h>
